@@ -53,7 +53,13 @@ var Application = GObject.registerClass({
                              GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
                              _('Print version and exit'), null);
         this.connect('handle-local-options', (o, dict) => {
-            let v = dict.lookup_value('test-instance', null);
+            let v = dict.lookup_value('version', null);
+            if (v && v.get_boolean()) {
+                print(`Polari ${pkg.version}`);
+                return 0;
+            }
+
+            v = dict.lookup_value('test-instance', null);
             if (v && v.get_boolean())
                 this._maybeMakeNonUnique();
 
@@ -69,12 +75,6 @@ var Application = GObject.registerClass({
                 return 0;
             }
 
-            v = dict.lookup_value('version', null);
-            if (v && v.get_boolean()) {
-                print(`Polari ${pkg.version}`);
-                return 0;
-            }
-
             return -1;
         });
     }
@@ -526,7 +526,7 @@ var Application = GObject.registerClass({
             return true;
         }
 
-        let path = `${GLib.get_user_cache_dir()}/polari/initial-setup-completed`;
+        let path = `${GLib.get_user_data_dir()}/polari/initial-setup-completed`;
         let f = Gio.File.new_for_path(path);
         try {
             this._touchFile(f);
@@ -618,15 +618,15 @@ var Application = GObject.registerClass({
         if (data)
             return data;
 
-        let params = Connections.getAccountParams(account);
+        let params = account.getConnectionParams();
         let server = params['server'];
         let accountName = params['account'];
         let port = params['port'];
         debug(`Failed to connect to ${server} with username ${accountName}`);
 
         let accountServers = [];
-        if (this._networksManager.getAccountIsPredefined(account))
-            accountServers = this._networksManager.getNetworkServers(account.service);
+        if (account.predefined)
+            accountServers = account.getServers();
 
         data = {
             retry: 0,
@@ -638,7 +638,7 @@ var Application = GObject.registerClass({
     }
 
     _getTrimmedAccountName(account) {
-        let params = Connections.getAccountParams(account);
+        let params = account.getConnectionParams();
         return params.account.replace(/_+$/, '');
     }
 
