@@ -157,8 +157,8 @@ var MainWindow = GObject.registerClass({
         });
 
         this._accountsMonitor = AccountsMonitor.getDefault();
-        this._accountsMonitor.connect('accounts-changed',
-                                      this._onAccountsChanged.bind(this));
+        this._accountsChangedId = this._accountsMonitor.connect(
+            'accounts-changed', this._onAccountsChanged.bind(this));
         this._onAccountsChanged(this._accountsMonitor);
 
         this._roomManager = RoomManager.getDefault();
@@ -175,7 +175,10 @@ var MainWindow = GObject.registerClass({
         this._userListAction = app.lookup_action('user-list');
 
         app.connect('action-state-changed::user-list', (group, name, value) => {
-            this._userListPopover.visible = value.get_boolean();
+            if (value.get_boolean())
+                this._userListPopover.popup();
+            else
+                this._userListPopover.popdown();
         });
         this._userListPopover.connect('notify::visible', () => {
             if (!this._userListPopover.visible)
@@ -242,6 +245,8 @@ var MainWindow = GObject.registerClass({
 
         this.active_room = null;
 
+        this._accountsMonitor.disconnect(this._accountsChangedId);
+
         this._roomManager.disconnect(this._roomsLoadedId);
         this._roomManager.disconnect(this._roomRemovedId);
 
