@@ -23,15 +23,14 @@ function _getTargetForContentType(contentType) {
 
 var PasteManager = class {
     pasteContent(content, title, callback) {
-        if (typeof content == 'string') {
+        if (typeof content == 'string')
             Utils.gpaste(content, title, callback);
-        } else if (content instanceof GdkPixbuf.Pixbuf) {
+        else if (content instanceof GdkPixbuf.Pixbuf)
             Utils.imgurPaste(content, title, callback);
-        } else if (content.query_info_async) {
+        else if (content.query_info_async)
             this._pasteFile(content, title, callback);
-        } else {
+        else
             throw new Error('Unhandled content type');
-        }
     }
 
     _pasteFile(file, title, callback) {
@@ -53,12 +52,12 @@ var PasteManager = class {
         let contentType = fileInfo.get_content_type();
         let targetType = _getTargetForContentType(contentType);
 
-        if (targetType == DndTargetType.TEXT)
+        if (targetType == DndTargetType.TEXT) {
             file.load_contents_async(null, (f, res) => {
                 let [, contents] = f.load_contents_finish(res);
                 Utils.gpaste(contents.toString(), title, callback);
             });
-        else if (targetType == DndTargetType.IMAGE)
+        } else if (targetType == DndTargetType.IMAGE) {
             file.read_async(GLib.PRIORITY_DEFAULT, null, (f, res) => {
                 let stream = f.read_finish(res);
                 GdkPixbuf.Pixbuf.new_from_stream_async(stream, null, (s, res) => {
@@ -66,8 +65,9 @@ var PasteManager = class {
                     Utils.imgurPaste(pixbuf, title, callback);
                 });
             });
-        else
+        } else {
             callback(null);
+        }
     }
 };
 
