@@ -33,7 +33,6 @@ var RoomRow = GObject.registerClass({
         this._room = room;
         this._popover = null;
 
-        this._popoverVisibleChangedId = 0;
         this._connectingTimeoutId = 0;
 
         this._icon.gicon = room.icon;
@@ -59,19 +58,13 @@ var RoomRow = GObject.registerClass({
         }
 
         this.connect('destroy', () => {
-            if (this._popoverVisibleChangedId)
-                this._popover.disconnect(this._popoverVisibleChangedId);
-            this._popoverVisibleChangedId = 0;
-
             room.disconnect(channelChangedId);
             this._channelSignals.forEach(id => {
                 room.channel.disconnect(id);
             });
             if (connectionStatusChangedId)
                 this.account.disconnect(connectionStatusChangedId);
-            if (this._connectingTimeoutId)
-                GLib.source_remove(this._connectingTimeoutId);
-            this._connectingTimeoutId = 0;
+            this._clearConnectingTimeout();
         });
 
         this._updatePending();
@@ -130,6 +123,7 @@ var RoomRow = GObject.registerClass({
                 return GLib.SOURCE_REMOVE;
             });
         } else {
+            this._clearConnectingTimeout();
             this._eventStack.visible_child_name = 'messages';
         }
     }
@@ -152,6 +146,7 @@ var RoomRow = GObject.registerClass({
 
         if (!this._room.channel)
             return;
+        this._clearConnectingTimeout();
         this._eventStack.visible_child_name = 'messages';
 
         for (let signal of ['message-received', 'pending-message-removed']) {
@@ -194,12 +189,17 @@ var RoomRow = GObject.registerClass({
                         `app.leave-room(("${this._room.id}", ""))`);
 
             this._popover = Gtk.Popover.new_from_model(this, menu);
-            this._popoverVisibleChangedId =
-                this._popover.connect('notify::visible',
-                                      _onPopoverVisibleChanged);
+            this._popover.connect('notify::visible',
+                                  _onPopoverVisibleChanged);
             this._popover.position = Gtk.PositionType.BOTTOM;
         }
-        this._popover.show();
+        this._popover.popup();
+    }
+
+    _clearConnectingTimeout() {
+        if (this._connectingTimeoutId)
+            GLib.source_remove(this._connectingTimeoutId);
+        this._connectingTimeoutId = 0;
     }
 });
 
